pub(super) async fn set_tree_view_message(
env: &MountainEnvironment,
view_identifier: String,
message: Option<String>,
) -> Result<(), CommonError>Expand description
Updates the tree view message displayed in the UI.
pub(super) async fn set_tree_view_message(
env: &MountainEnvironment,
view_identifier: String,
message: Option<String>,
) -> Result<(), CommonError>Updates the tree view message displayed in the UI.